#[repr(C)]pub struct UsbEndpointDescriptor {
pub b_length: u8,
pub b_descriptor_type: u8,
pub b_endpoint_address: u8,
pub bm_attributes: u8,
pub w_max_packet_size: u16,
pub b_interval: u8,
}Fields
b_length: u8b_descriptor_type: u8b_endpoint_address: u8bm_attributes: u8w_max_packet_size: u16b_interval: u8Trait Implementations
Sourceimpl Clone for UsbEndpointDescriptor
impl Clone for UsbEndpointDescriptor
Sourcefn clone(&self) -> UsbEndpointDescriptor
fn clone(&self) -> UsbEndpointDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for UsbEndpointDescriptor
Sourceimpl Debug for UsbEndpointDescriptor
impl Debug for UsbEndpointDescriptor
Sourceimpl<D: ResourceDialect> Decode<UsbEndpointDescriptor, D> for UsbEndpointDescriptor
impl<D: ResourceDialect> Decode<UsbEndpointDescriptor, D> for UsbEndpointDescriptor
Sourceimpl<D: ResourceDialect> Encode<UsbEndpointDescriptor, D> for &UsbEndpointDescriptor
impl<D: ResourceDialect> Encode<UsbEndpointDescriptor, D> for &UsbEndpointDescriptor
Sourceimpl<D: ResourceDialect, T0: Encode<u8, D>, T1: Encode<u8, D>, T2: Encode<u8, D>, T3: Encode<u8, D>, T4: Encode<u16, D>, T5: Encode<u8, D>> Encode<UsbEndpointDescriptor, D> for (T0, T1, T2, T3, T4, T5)
impl<D: ResourceDialect, T0: Encode<u8, D>, T1: Encode<u8, D>, T2: Encode<u8, D>, T3: Encode<u8, D>, T4: Encode<u16, D>, T5: Encode<u8, D>> Encode<UsbEndpointDescriptor, D> for (T0, T1, T2, T3, T4, T5)
impl Eq for UsbEndpointDescriptor
Sourceimpl Hash for UsbEndpointDescriptor
impl Hash for UsbEndpointDescriptor
Sourceimpl Ord for UsbEndpointDescriptor
impl Ord for UsbEndpointDescriptor
Sourcefn cmp(&self, other: &UsbEndpointDescriptor) -> Ordering
fn cmp(&self, other: &UsbEndpointDescriptor) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UsbEndpointDescriptor
impl PartialEq for UsbEndpointDescriptor
Sourcefn eq(&self, other: &UsbEndpointDescriptor) -> bool
fn eq(&self, other: &UsbEndpointDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UsbEndpointDescriptor
impl PartialOrd for UsbEndpointDescriptor
impl Persistable for UsbEndpointDescriptor
impl StructuralPartialEq for UsbEndpointDescriptor
Sourceimpl TypeMarker for UsbEndpointDescriptor
impl TypeMarker for UsbEndpointDescriptor
Sourcetype Owned = UsbEndpointDescriptor
type Owned = UsbEndpointDescriptor
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for UsbEndpointDescriptor
impl ValueTypeMarker for UsbEndpointDescriptor
Sourcetype Borrowed<'a> = &'a UsbEndpointDescriptor
type Borrowed<'a> = &'a UsbEndpointDescriptor
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for UsbEndpointDescriptor
impl RefUnwindSafe for UsbEndpointDescriptor
impl Send for UsbEndpointDescriptor
impl Sync for UsbEndpointDescriptor
impl Unpin for UsbEndpointDescriptor
impl UnsafeUnpin for UsbEndpointDescriptor
impl UnwindSafe for UsbEndpointDescriptor