#[repr(C)]pub struct UsbSsEpCompDescriptor {
pub b_length: u8,
pub b_descriptor_type: u8,
pub b_max_burst: u8,
pub bm_attributes: u8,
pub w_bytes_per_interval: u16,
}Fields
b_length: u8b_descriptor_type: u8b_max_burst: u8bm_attributes: u8w_bytes_per_interval: u16Trait Implementations
Sourceimpl Clone for UsbSsEpCompDescriptor
impl Clone for UsbSsEpCompDescriptor
Sourcefn clone(&self) -> UsbSsEpCompDescriptor
fn clone(&self) -> UsbSsEpCompDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for UsbSsEpCompDescriptor
Sourceimpl Debug for UsbSsEpCompDescriptor
impl Debug for UsbSsEpCompDescriptor
Sourceimpl<D: ResourceDialect> Decode<UsbSsEpCompDescriptor, D> for UsbSsEpCompDescriptor
impl<D: ResourceDialect> Decode<UsbSsEpCompDescriptor, D> for UsbSsEpCompDescriptor
Sourceimpl<D: ResourceDialect> Encode<UsbSsEpCompDescriptor, D> for &UsbSsEpCompDescriptor
impl<D: ResourceDialect> Encode<UsbSsEpCompDescriptor, D> for &UsbSsEpCompDescriptor
Sourceimpl<D: ResourceDialect, T0: Encode<u8, D>, T1: Encode<u8, D>, T2: Encode<u8, D>, T3: Encode<u8, D>, T4: Encode<u16, D>> Encode<UsbSsEpCompDescriptor, D> for (T0, T1, T2, T3, T4)
impl<D: ResourceDialect, T0: Encode<u8, D>, T1: Encode<u8, D>, T2: Encode<u8, D>, T3: Encode<u8, D>, T4: Encode<u16, D>> Encode<UsbSsEpCompDescriptor, D> for (T0, T1, T2, T3, T4)
impl Eq for UsbSsEpCompDescriptor
Sourceimpl Hash for UsbSsEpCompDescriptor
impl Hash for UsbSsEpCompDescriptor
Sourceimpl Ord for UsbSsEpCompDescriptor
impl Ord for UsbSsEpCompDescriptor
Sourcefn cmp(&self, other: &UsbSsEpCompDescriptor) -> Ordering
fn cmp(&self, other: &UsbSsEpCompDescriptor) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UsbSsEpCompDescriptor
impl PartialEq for UsbSsEpCompDescriptor
Sourcefn eq(&self, other: &UsbSsEpCompDescriptor) -> bool
fn eq(&self, other: &UsbSsEpCompDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UsbSsEpCompDescriptor
impl PartialOrd for UsbSsEpCompDescriptor
impl Persistable for UsbSsEpCompDescriptor
impl StructuralPartialEq for UsbSsEpCompDescriptor
Sourceimpl TypeMarker for UsbSsEpCompDescriptor
impl TypeMarker for UsbSsEpCompDescriptor
Sourcetype Owned = UsbSsEpCompDescriptor
type Owned = UsbSsEpCompDescriptor
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for UsbSsEpCompDescriptor
impl ValueTypeMarker for UsbSsEpCompDescriptor
Sourcetype Borrowed<'a> = &'a UsbSsEpCompDescriptor
type Borrowed<'a> = &'a UsbSsEpCompDescriptor
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for UsbSsEpCompDescriptor
impl RefUnwindSafe for UsbSsEpCompDescriptor
impl Send for UsbSsEpCompDescriptor
impl Sync for UsbSsEpCompDescriptor
impl Unpin for UsbSsEpCompDescriptor
impl UnsafeUnpin for UsbSsEpCompDescriptor
impl UnwindSafe for UsbSsEpCompDescriptor